;; Generated package description from ivy.el  -*- no-byte-compile: t -*-
(define-package "ivy" "0.13.4.0.20230326.132001" "Incremental Vertical completYon" '((emacs "24.5")) :commit "61c1b96aade44d37f2dfc675ec7418a590387c46" :authors '(("Oleh Krehel" . "ohwoeowho@gmail.com")) :maintainer '("Oleh Krehel" . "ohwoeowho@gmail.com") :keywords '("matching") :url "https://github.com/abo-abo/swiper")
